****REPLICATION
clear all
set more 1
cd "C:\Users\ddoherty\Documents\Filibuster Support\Replication Archive\tables"

*****************************************************
***** CCES ANALYSIS *********************************
*****************************************************
use "..\cces11_replication.dta", clear

** DEMOGRAPHICS
gen pid=v212d if v212d<=7
replace pid=(pid-4)/3
label var pid "Respondent Party ID (-1=S Dem; 1=S Rep)"


gen age=v278
label var age "Age (in years)"
gen age2=(age*age)/100
label var age2 "Age-squared/100"

gen educ=v213
label var educ "Education (1=No HS; 6=post-grad)"
gen income=v246
qui sum income
gen incomemis=(income>16)
replace income = r(mean) if income>16

label var income "Income (1=<$10k; 16=$500k+; RF/Miss=mean)"
label var incomemis "Income Refused (1=yes)"

tab v211, gen(race_)
gen r_white=race_1
gen r_black=race_2
gen r_hispanic=race_3
gen r_other=race_4+race_5+race_6+race_7
label var r_white "White (1=yes)"
label var r_black "Black (1=yes)"
label var r_hispanic "Hispanic (1=yes)"
label var r_other "Other race / Skipped (1=yes)"

recode v208 (1=0) (2=1) (*=.),gen(female)
label var female "Female (1=yes)"

recode v244 (1=4) (2=3) (3=2) (4 5=1),gen(polinterest)
label var polinterest "Interest in politics (1=Hardly at all/DK; 4=Most of the time)"

gen ideology=v243
replace ideology=3 if ideology>5
replace ideology=(ideology-3)/2
label var ideology "Ideology (-1=v. liberal; 1=v. conservative)"


*** TREATMENTS
replace yal001=. if yal001>4
gen policy_pref=((yal001-1)/3*2-1)*-1
label var policy_pref "Policy Preference (-1=Decrease a lot; 1=Increase a lot)"
gen policy_pref_dich=policy_pref>0
label var policy_pref_dich "Policy Preference (0=decrease, 1=increase)"


* Generate Treatment Variables
tab yal161_treat, gen(treat_)
egen policy_increase=rowmax(treat_1 treat_2 treat_3 treat_4 treat_5 treat_6)
replace policy_increase=-1 if policy_increase==0
label var policy_increase "Policy Direction (-1=decrease; 1=increase)"

gen policy_supp=policy_pref*policy_increase
label var policy_supp "Respondent Policy Pref. (-1=S Oppose 1=S Support)"
gen policy_dich=policy_supp>0
label var policy_dich "Resp. Supports Bill (1=yes)"

egen national_oppose=rowmax(treat_1 treat_2 treat_3 treat_7 treat_8 treat_9)
label var national_oppose "Nation Opposes (1=yes)"

egen state_oppose=rowmax(treat_4 treat_5 treat_6 treat_10 treat_11 treat_12)
label var state_oppose "State Opposes (1=yes)"

egen action_1=rowmax(treat_2 treat_5 treat_8 treat_11)
egen action_2=rowmax(treat_1 treat_4 treat_7 treat_10)
egen action_3=rowmax(treat_3 treat_6 treat_9 treat_12)
label var action_1 "Symbolic"
label var action_2 "Majoritarian"
label var action_3 "Filibuster"
gen action=action_1+action_2*2+action_3*3
label var action "Representative Action"

foreach i in state_oppose action_1 action_2 action_3{
local label : variable label `i'
gen policy_suppX`i'=policy_supp*`i'
gen policy_dichX`i'=policy_dich*`i'
label var policy_suppX`i' "Resp. Supports Bill x `label'"
label var policy_dichX`i' "Resp. Supports Bill x `label'"
}

forvalues i=1/3{
local label : variable label action_`i'
gen state_opposeXaction_`i'=state_oppose*action_`i'
label var state_opposeXaction_`i' "State Oppose x `label'"
gen dichXstate_opposeXaction_`i'=policy_dich*state_oppose*action_`i'
label var dichXstate_opposeXaction_`i' "Resp. Supports Bill x State Oppose x `label'"
}

***OUTCOMES
gen rate_rep=yal161 if yal161<=100
gen vote_int=yal162 if yal162<=100
label var rate_rep "Rate Representative (0-100)"
label var vote_int "Vote Intent (0-100)"
gen eval_rep=(rate_rep+vote_int)/20
label var eval_rep "Evaluation of Representative (0-10)"

gen majority_rule=(yal164-3) if yal164<=5
label var majority_rule "Support for Majority Rule (-2 to 2)"

***SET SAMPLE AND CHECK BALANCE
reg yal161_treat r_black r_hispanic r_other female income incomemis educ age pid ideol polinterest policy_supp eval_rep majority_rule
keep if e(sample)
mlogit yal161_treat r_black r_hispanic r_other female income incomemis educ age pid ideol polinterest 
corr rate_rep vote_int

***SUMMARY STATS
outsum policy_dich eval_rep r_white r_black r_hispanic r_other female income incomemis educ age pid ideol polinterest using "s1_summary.out", replace bracket

******************************************************
********** TABLE 2: Means by Treatment Condition *****
******************************************************
foreach i in eval_rep{
table action state_oppose, c(mean `i' freq)
}


***REGRESSIONS
reg eval_rep policy_dich state_oppose action_2 action_3, r
lincom action_2-action_3
local fx=r(estimate)
test action_2==action_3
outreg using "table_3.out", se bracket rdec(3) adec(3) 3aster replace addstat("Difference between Majoritarian and Filibuster",`fx',"Difference between Majoritarian and Filibuster (p-value)",r(p))

reg eval_rep policy_dich state_oppose action_2 action_3 state_opposeXaction_2 state_opposeXaction_3, r
test state_opposeXaction_2 state_opposeXaction_3
outreg using "table_4.out", se bracket rdec(3) adec(3) 3aster replace addstat("Test of Joint Significance of Interactions (p-value)",r(p))

***RESPONDENT PREFERENCE REGRESSIONS
forvalues i=1/3{
reg eval_rep policy_dich state_oppose policy_dichXstate_oppose if action_`i'==1, r
if `i'==1{
outreg using "s3_iss_mod_top.out", se bracket rdec(3) 3aster replace 
}
else{
outreg using "s3_iss_mod_top.out", se bracket rdec(3) 3aster append
}
}


reg eval_rep policy_dich action_2 action_3 policy_dichXaction_2 policy_dichXaction_3 state_oppose policy_dichXstate_oppose, r
lincom action_2-action_3
local opp_est=r(estimate)
test action_2==action_3
local opp_p=r(p)
lincom (action_2+policy_dichXaction_2)-(action_3+policy_dichXaction_3)
local supp_est=r(estimate)
test (action_2+policy_dichXaction_2)==(action_3+policy_dichXaction_3)
local supp_p=r(p)
test policy_dichXaction_2==policy_dichXaction_3
local d_in_d=r(p)
outreg using "table_5.out", se bracket rdec(3) 3aster replace adec(3) addstat("Maj.-Filibuster (Opponents)",`opp_est',"p-value",`opp_p',"Maj.-Filibuster (Supporters)",`supp_est',"p-value",`supp_p',"Diff-in-Diff (p-value)",`d_in_d')

gen pol_2=0 
gen pol_3=0
gen cces=1

keep eval_rep policy_dich action_1 action_2 action_3 policy_dichXaction_2 policy_dichXaction_3 state_oppose policy_dichXstate_oppose state_opposeXaction_2 state_opposeXaction_3 pol_2 pol_3 cces
save "stripped_cces.dta", replace


**********************************************
*********MTURK FOLLOW UP *********************
**********************************************
clear all
set matsize 800
use "..\mturk_replication.dta", clear


** DEMOGRAPHICS
*Party ID
rename generallyspeakingdoyouusuallythi pid_stem
rename wouldyoucallyourselfastrongdemoc pid_dstr
rename wouldyoucallyourselfastrongrepub pid_rstr
rename doyouthinkofyourselfasclosertoth pid_lean
egen pid=rmean(pid_dstr pid_rstr pid_lean)
drop if round(pid)!=pid
replace pid=pid/3
label var pid "Respondent Party ID (-1=S Dem; 1=S Rep)"

recode pid_stem (1=-1) (2=1) (3 4=0) (*=.), gen(pid3)
label var pid3 "Respondent 3-pt. Party ID (-1=Dem; 0=Ind; 1=Rep)"

gen indep_pure=pid==0
gen indep_all=pid3==0
label var indep_pure "Respondent is Pure Independent (1=yes)"
label var indep_all "Respondent is Independent (1=yes)"

rename whatistheyearofyourbirth yob
gen age=2012-yob
label var age "Age (in years)"
gen age2=(age*age)/100
label var age2 "Age-squared/100"
drop if age<18

rename whatisthehighestlevelofeducation educ
label var educ "Education (1=No HS; 6=post-grad)"
rename whatwasyourtotalfamilyincomein20 income
label var income "Income (1=<$10k; 14=$150k+; RF/Miss=mean)"
gen incomemis=(income==15)
qui sum income if income==15
replace income=r(mean) if income==15
label var incomemis "Income Refused (1=yes)"

tab whatracialorethnicgrouporgroupsb,gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7
drop r_4-r_7
label var r_other "Other race / Skipped (1=yes)"
label var r_white "White (1=yes)"
label var r_black "Black (1=yes)"
label var r_hispanic "Hispanic (1=yes)"


rename whatisyourgender female
label var female "Female (1=yes)"

recode howinterestedareyouinpoliticsand (1=3) (2=2) (3=1) (*=.), gen(polinterest)
label var polinterest "Interest in politics (1=not at all; 3=very interested)"

gen ideology=wehearalotoftalkthesedaysaboutli/3
label var ideology "Ideology (-1=v. liberal; 1=v. conservative)"

*****TREATMENTS
tab context, gen(cont_)
rename cont_1 action_3
rename cont_2 action_2
rename cont_3 action_1
label var action_1 "Symbolic"
label var action_2 "Majoritarian"
label var action_3 "Filibuster"
gen action=action_1+(action_2*2)+(action_3*3)

tab policy, gen(pol_)
label var pol_1 "Policy: Unemployment"
label var pol_2 "Policy: Environmental Enforcement"
label var pol_3 "Policy: National Defense"

gen pol_feelings=assistancetotheunemployedbelowis if pol_1
replace pol_feelings=enforcingenvironmentalregulation if pol_2
replace pol_feelings=nationaldefensebelowisalistoffed if pol_3
replace pol_feelings =-1*(((pol_feelings-1)*2/3)-1)
tab policy_dir, gen(dir_)
drop dir_2
recode dir_1 (1=1) (0=-1),gen(pol_dir)
gen policy_supp=pol_dir*pol_feelings
label var policy_supp "Respondent Policy Pref. (-1=S Oppose 1=S Support)"
gen policy_dich=policy_supp>0
label var policy_dich "Resp. Supports Bill (1=yes)"


gen eval_rep=(basedonwhatyoujustreadhowwouldyo+ifyoulivedinthissenatorsstatehow)/2
label var eval_rep "Evaluation of Representative (0-10)"

tab publicopinion, gen(po_)
drop po_1
rename po_2 state_oppose
label var state_oppose "State Opposes (1=yes)"

foreach i in state_oppose action_1 action_2 action_3{
local label : variable label `i'
gen policy_suppX`i'=policy_supp*`i'
gen policy_dichX`i'=policy_dich*`i'
label var policy_suppX`i' "Resp. Supports Bill x `label'"
label var policy_dichX`i' "Resp. Supports Bill x `label'"
}

forvalues i=1/3{
local label : variable label action_`i'
gen state_opposeXaction_`i'=state_oppose*action_`i'
label var state_opposeXaction_`i' "State Oppose x `label'"
gen dichXstate_opposeXaction_`i'=policy_dich*state_oppose*action_`i'
label var dichXstate_opposeXaction_`i' "Resp. Supports Bill x State Oppose x `label'"
}


gen majority_rule=majorityruleistheonlyfairwayfora-3
gen minority_rights=whenagroupmakesadecisionitisimpo-3
label var majority_rule "Support for Majority Rule (-2 to 2)"
label var minority_rights "Support for Minority Rights (-2 to 2)"

***SET SAMPLE AND CHECK BALANCE
reg eval_rep r_black r_hispanic r_other female income incomemis educ age pid ideol polinterest policy_supp majority_rule minority_rights
keep if e(sample)
*Gen full treatment condition measure for balance test
gen treat=action_1+(action_2*2)+(action_3*3)+(state_oppose*10)+(pol_dir*100)+(pol_1*1000)+(pol_2*10000)+(pol_3*100000)
egen trt_grp=group(treat)
mlogit trt_grp r_black r_hispanic r_other female income incomemis educ age pid ideol polinterest, r
corr basedonwhatyoujustreadhowwouldyo ifyoulivedinthissenatorsstatehow
****SUMMARY STATS
outsum policy_dich eval_rep r_white r_black r_hispanic r_other female income incomemis educ age pid ideol polinterest majority_rule minority_rights using "s1_summary", append bracket

******************************************************
********** TABLE 2: Means by Treatment Condition *****
******************************************************
foreach i in eval_rep{
table action state_oppose, c(mean `i' freq)
}


***REGRESSIONS
reg eval_rep policy_dich state_oppose action_2 action_3 pol_2 pol_3, r
lincom action_2-action_3
local fx=r(estimate)
test action_2==action_3
outreg using "table_3.out", se bracket rdec(3) adec(3) 3aster append addstat("Difference between Majoritarian and Filibuster",`fx',"Difference between Majoritarian and Filibuster (p-value)",r(p))

reg eval_rep policy_dich state_oppose action_2 action_3 state_opposeXaction_2 state_opposeXaction_3 pol_2 pol_3, r
test state_opposeXaction_2 state_opposeXaction_3
outreg using "table_4.out", se bracket rdec(3) adec(3) 3aster append addstat("Test of Joint Significance of Interactions (p-value)",r(p))

forvalues i=1/3{
reg eval_rep policy_dich state_oppose action_2 action_3 if pol_`i', r
lincom action_2-action_3
local fx=r(estimate)
test action_2==action_3
outreg using "table_3.out", se bracket rdec(3) adec(3) 3aster append addstat("Difference between Majoritarian and Filibuster",`fx',"Difference between Majoritarian and Filibuster (p-value)",r(p))
reg eval_rep policy_dich state_oppose action_2 action_3 state_opposeXaction_2 state_opposeXaction_3 if pol_`i', r
test state_opposeXaction_2 state_opposeXaction_3
outreg using "table_4.out", se bracket rdec(3) adec(3) 3aster append addstat("Test of Joint Significance of Interactions (p-value)",r(p))
}

****SIGNIFICANT VARIATION ACROSS POLICIES?
foreach i in policy_dich state_oppose action_2 action_3{
local label : variable label `i'
gen `i'Xpol_1=`i'*pol_1
gen `i'Xpol_2=`i'*pol_2
gen `i'Xpol_3=`i'*pol_3
label var `i'Xpol_1 "`label' x Unemployment"
label var `i'Xpol_2 "`label' x Environmental Enforcement"
label var `i'Xpol_3 "`label' x National Defense"
}

reg eval_rep policy_dich state_oppose action_2 action_3 pol_2 pol_3 policy_dichXpol_2 policy_dichXpol_3 state_opposeXpol_2 state_opposeXpol_3 action_2Xpol_2 action_3Xpol_2 action_2Xpol_3 action_3Xpol_3, r
test policy_dichXpol_2 state_opposeXpol_2 action_2Xpol_2 action_3Xpol_2 policy_dichXpol_3 state_opposeXpol_3 action_2Xpol_3 action_3Xpol_3
local all=r(p)
test policy_dichXpol_2 policy_dichXpol_3 
local policy=r(p)
test state_opposeXpol_2 state_opposeXpol_3 
local state=r(p)
test action_2Xpol_2 action_3Xpol_2 action_2Xpol_3 action_3Xpol_3
local action=r(p)
outreg using "s2_policy_var.out", se bracket rdec(3) 3aster replace adec(3) addstat("Joint Sig. of All Policy Interactions (p)",`all',"Joint Sig. of Policy Agreement Interactions",`policy',"Joint Sig. of State Opposition Interactions",`state',"Joint Sig. of Majoritarian and Filibuster Interactions",`action')

***RESPONDENT PREFERENCE REGRESSIONS

forvalues i=1/3{
reg eval_rep policy_dich state_oppose policy_dichXstate_oppose pol_2 pol_3 if action_`i'==1, r
outreg using "s3_iss_mod_bottom.out", se bracket rdec(3) 3aster append
}

forvalues i=1/3{
forvalues p=1/3{
reg eval_rep policy_dich state_oppose policy_dichXstate_oppose if action_`i'==1 & pol_`p'==1, r
if `i'==1 & `p'==1{
outreg using "s3_iss_mod_bottom.out", se bracket rdec(3) 3aster replace
}
else{
outreg using "s3_iss_mod_bottom.out", se bracket rdec(3) 3aster append
}
}
}

reg eval_rep policy_dich action_2 action_3 pol_2 pol_3 policy_dichXaction_2 policy_dichXaction_3 state_oppose policy_dichXstate_oppose, r
lincom action_2-action_3
local o_est=r(estimate)
test action_2==action_3
local o_p=r(p)

lincom (action_2+policy_dichXaction_2)-(action_3+policy_dichXaction_3)
local s_est=r(estimate)
test (action_2+policy_dichXaction_2)==(action_3+policy_dichXaction_3)
local s_p=r(p)

test policy_dichXaction_2==policy_dichXaction_3
local d_in_d=r(p)
outreg using "table_5.out", se bracket rdec(3) 3aster append adec(3) addstat("Maj.-Filibuster (Opponents)",`o_est',"p-value",`o_p',"Maj.-Filibuster (Supporters)",`s_est',"p-value",`s_p',"Diff-in-Diff (p-value)",`d_in_d')

forvalues i=1/3{
reg eval_rep policy_dich action_2 action_3 policy_dichXaction_2 policy_dichXaction_3 state_oppose policy_dichXstate_oppose if pol_`i', r
lincom action_2-action_3
local o_est=r(estimate)
test action_2==action_3
local o_p=r(p)
lincom (action_2+policy_dichXaction_2)-(action_3+policy_dichXaction_3)
local s_est=r(estimate)
test (action_2+policy_dichXaction_2)==(action_3+policy_dichXaction_3)
local s_p=r(p)
test policy_dichXaction_2==policy_dichXaction_3
local d_in_d=r(p)
outreg using "table_5.out", se bracket rdec(3) 3aster append adec(3) addstat("Maj.-Filibuster (Opponents)",`o_est',"p-value",`o_p',"Maj.-Filibuster (Supporters)",`s_est',"p-value",`s_p',"Diff-in-Diff (p-value)",`d_in_d')
}


***MAJORITY RULE?
foreach i in state_oppose action_2 action_3 {
gen majX`i'=majority_rule*`i'
gen minX`i'=minority_rights*`i'
}
label var majXstate_oppose "State Opposes x Support for Majority Rule"
label var majXaction_2 "Majoritarian x Support for Majority Rule"
label var majXaction_3 "Filibuster x Support for Majority Rule"

label var minXstate_oppose "State Opposes x Support for Minority Rights"
label var minXaction_2 "Majoritarian x Support for Minority Rights"
label var minXaction_3 "Filibuster x Support for Minority Rights"

reg eval_rep policy_dich state_oppose action_2 action_3 pol_2 pol_3 majority_rule majX* minority_rights minX*, r
test majXstate_oppose
local state=r(p)
test majXaction_2==-majXaction_3
local int=r(p)
test minXstate_oppose
local state_min=r(p)
test minXaction_2==-minXaction_3
local int_min=r(p)
outreg using "s4_maj_rule.out", se bracket rdec(3) 3aster replace adec(3) addstat("State Oppose Vary w/Support for Maj. Rule? (p-value)",`state',"M. v. F. Vary w/Support for Maj. Rule? (p-value)",`int',"State Oppose Vary w/Support for Min. Rights? (p-value)",`state_min',"M. v. F. Vary w/Support for Min. Rights? (p-value)",`int_min')

reg eval_rep state_oppose action_2 action_3 pol_2 pol_3 majority_rule majX* minority_rights minX* if policy_dich==0, r
test majXstate_oppose
local state=r(p)
test majXaction_2==-majXaction_3
local int=r(p)
test minXstate_oppose
local state_min=r(p)
test minXaction_2==-minXaction_3
local int_min=r(p)
outreg using "s4_maj_rule.out", se bracket rdec(3) 3aster append adec(3) addstat("State Oppose Vary w/Support for Maj. Rule? (p-value)",`state',"M. v. F. Vary w/Support for Maj. Rule? (p-value)",`int',"State Oppose Vary w/Support for Min. Rights? (p-value)",`state_min',"M. v. F. Vary w/Support for Min. Rights? (p-value)",`int_min')

reg eval_rep state_oppose action_2 action_3 pol_2 pol_3 majority_rule majX* minority_rights minX* if policy_dich==1, r
test majXstate_oppose
local state=r(p)
test majXaction_2==-majXaction_3
local int=r(p)
test minXstate_oppose
local state_min=r(p)
test minXaction_2==-minXaction_3
local int_min=r(p)
outreg using "s4_maj_rule.out", se bracket rdec(3) 3aster append adec(3) addstat("State Oppose Vary w/Support for Maj. Rule? (p-value)",`state',"M. v. F. Vary w/Support for Maj. Rule? (p-value)",`int',"State Oppose Vary w/Support for Min. Rights? (p-value)",`state_min',"M. v. F. Vary w/Support for Min. Rights? (p-value)",`int_min')

************STACK DATA**************
append using "stripped_cces.dta"
replace cces=0 if cces==.
label var cces "CCES Data (1=yes)"
reg eval_rep policy_dich state_oppose action_2 action_3 pol_2 pol_3 cces, r
lincom action_2-action_3
local fx=r(estimate)
test action_2==action_3
outreg using "table_3.out", se bracket rdec(3) adec(3) 3aster append addstat("Difference between Majoritarian and Filibuster",`fx',"Difference between Majoritarian and Filibuster (p-value)",r(p))

reg eval_rep policy_dich state_oppose action_2 action_3 state_opposeXaction_2 state_opposeXaction_3 pol_2 pol_3 cces, r
test state_opposeXaction_2 state_opposeXaction_3
outreg using "table_4.out", se bracket rdec(3) adec(3) 3aster append addstat("Test of Joint Significance of Interactions (p-value)",r(p))

reg eval_rep policy_dich action_2 action_3 pol_2 pol_3 policy_dichXaction_2 policy_dichXaction_3 state_oppose policy_dichXstate_oppose cces, r
lincom action_2-action_3
local o_est=r(estimate)
test action_2==action_3
local o_p=r(p)
lincom (action_2+policy_dichXaction_2)-(action_3+policy_dichXaction_3)
local s_est=r(estimate)
test (action_2+policy_dichXaction_2)==(action_3+policy_dichXaction_3)
local s_p=r(p)
test policy_dichXaction_2==policy_dichXaction_3
local d_in_d=r(p)
outreg using "table_5.out", se bracket rdec(3) 3aster append adec(3) addstat("Maj.-Filibuster (Opponents)",`o_est',"p-value",`o_p',"Maj.-Filibuster (Supporters)",`s_est',"p-value",`s_p',"Diff-in-Diff (p-value)",`d_in_d')
forvalues i=1/3{
reg eval_rep policy_dich state_oppose policy_dichXstate_oppose pol_2 pol_3 cces if action_`i'==1, r
outreg using "s3_iss_mod_top.out", se bracket rdec(3) 3aster append
}
